# mzapy
A Python package that provides an interface to raw MS data in the MZA format.

#### Contributors:
- Dylan Ross (dylan.ross@pnnl.gov)
- Aivett Bilbao (aivett.bilbao@pnnl.gov)
- Joon-Yong Lee (junyoni@gmail.com)
- Xueyun Zheng (xueyun.zheng@pnnl.gov)

<hr>


Documentation is available at https://mzapy.readthedocs.io/

